==> webkit2gtk_2.35.1.orig.tar.xz: webkitgtk-2.35.1/Source/WebCore/layout/formattingContexts/inline/InlineItemsBuilder.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(LAYOUT_FORMATTING_CONTEXT)

#include "InlineFormattingState.h"
#include "LayoutContainerBox.h"
#include <wtf/text/StringBuilder.h>

namespace WebCore {
namespace Layout {
class InlineTextBox;

class InlineItemsBuilder {
public:
    InlineItemsBuilder(const ContainerBox& formattingContextRoot, InlineFormattingState&);
    InlineItems build();

private:
    void collectInlineItems(InlineItems&);
    void breakAndComputeBidiLevels(InlineItems&);
    void computeInlineTextItemWidths(InlineItems&);

    void handleTextContent(const InlineTextBox&, InlineItems&);
    void handleInlineBoxStart(const Box&, InlineItems&);
    void handleInlineBoxEnd(const Box&, InlineItems&);
    void handleInlineLevelBox(const Box&, InlineItems&);
    
    bool hasSeenBidiContent() const { return m_hasSeenBidiContent; }

    const ContainerBox& root() const { return m_root; }

    const ContainerBox& m_root;
    // FIXME: We should not need this here. This is only required by the out of flow boxes.
    InlineFormattingState& m_formattingState;
    bool m_hasSeenBidiContent { false };
};

}
}

#endif

==> webkit2gtk_2.39.3.orig.tar.xz: webkitgtk-2.39.3/Source/WebCore/layout/formattingContexts/inline/InlineItemsBuilder.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "InlineFormattingState.h"
#include "LayoutElementBox.h"
#include <wtf/text/StringBuilder.h>

namespace WebCore {
namespace Layout {
class InlineTextBox;

class InlineItemsBuilder {
public:
    InlineItemsBuilder(const ElementBox& formattingContextRoot, InlineFormattingState&);
    InlineItems build();

private:
    void collectInlineItems(InlineItems&);
    void breakAndComputeBidiLevels(InlineItems&);
    void computeInlineTextItemWidths(InlineItems&);

    void handleTextContent(const InlineTextBox&, InlineItems&);
    void handleInlineBoxStart(const Box&, InlineItems&);
    void handleInlineBoxEnd(const Box&, InlineItems&);
    void handleInlineLevelBox(const Box&, InlineItems&);
    
    bool needsVisualReordering() const { return m_needsVisualReordering; }

    const ElementBox& root() const { return m_root; }

    const ElementBox& m_root;
    // FIXME: We should not need this here. This is only required by the out of flow boxes.
    InlineFormattingState& m_formattingState;
    bool m_needsVisualReordering { false };
};

}
}
